ORD fields

The full list of ORD fields, grouped by category. Tables / File lists the tables each field appears in, Format is the serialisation (csv or json), and Current Oasis name maps the ORD field to the legacy OasisLMF column name where one exists.

Results

Field

Tables / File

Format

Current Oasis name

Description

SummaryId

ALT,EPT,PSEPT,MELT,MPLT,SELT,SPLT,QELT,QPLT

csv

summary_id

Summary ID

SampleType

ALT,MELT

csv

type

Indicator whether mean loss is analytical (SampleType=1) or sampled (SampleType=2)

MeanLoss

ALT,MELT,MPLT

csv

mean

Mean loss

SDLoss

ALT,MELT,MPLT

csv

standard_deviation

Standard Deviation

SourceExposure

ALT

csv

exposure_value

Exposure Value

FootprintExposure

MELT,MPLT

csv

Exposure in the event footprint

ImpactedExposure

SELT,SPLT

csv

Exposure impacted by the event (where loss > 0)

SampleId

PSEPT,SELT,SPLT

csv

sidx

Sample number

ReturnPeriod

EPT, PSEPT

csv

return_period

Return period

Loss

EPT,PSEPT,SELT,SPLT,QELT,QPLT

csv

loss

Loss

SampleType

MPLT

csv

Indicator whether mean loss is analytical (SampleType=1) or sampled (SampleType=2)

EventId

MELT,MPLT,SELT,SPLT,QELT,QPLT

csv

event_id

Event ID

Period

MPLT,QPLT,SPLT

csv

period_no

Period No

Year

MPLT,QPLT,SPLT

csv

occ_year

Occurrence Year

Month

MPLT,QPLT,SPLT

csv

occ_month

Occurrence Month

Day

MPLT,QPLT,SPLT

csv

occ_day

Occurrence Day

Hour

MPLT,QPLT,SPLT

csv

Occurrence Hour

Minute

MPLT,QPLT,SPLT

csv

Occurrence Minute

EventRate

MELT

csv

Rate representing the summary of the occurrence table event frequency

SDLossCor

MELT,MPLT

csv

Correlated Standard Deviation

SDLossInd

MELT,MPLT

csv

Independent Standard Deviation

Quantile

QELT,QPLT

csv

Loss Quantile

ImpactedNumLocs

SELT,SPLT

csv

Number of locations that have been affected by the event.

MeanImpactedNumLocs

MELT,MPLT

csv

Mean number of locations that have been affected by the event (across all samples)

MaxImpacted NumLocs

MELT,MPLT

csv

Max number of locations that have been affected by the event (across all samples).

PerilCode

ALT,EPT,PSEPT,MELT,MPLT,SELT,SPLT,QELT,QPLT

csv

Peril / subperil for which losses are produced

Coverage

ALT,EPT,PSEPT,MELT,MPLT,SELT,SPLT,QELT,QPLT

csv

Coverage (building, contents, BI or other)

PeriodWeight

MPLT,QPLT,SPLT

csv

Period Weight: used to give a weighting to periods when simulating.

SummaryId

DOMEXP,REJEXP

csv

Summary ID

SourceExposure

DOMEXP,REJEXP

csv

Source exposure

SourceNumLocs

DOMEXP,REJEXP,ALT

csv

Source number of locations

DomainExposure

DOMEXP

csv

Domain exposure

DomainNumLocs

DOMEXP

csv

Domain number of locations

SecModExposure

DOMEXP

csv

Exposure with at least one secondary modifier

SecModNumLocs

DOMEXP

csv

Number of locations with at least one secondary modifier

PortNumber

ELOG

csv

Portfolio number

AccNumber

ELOG

csv

Account number

LocNumber

ELOG

csv

Location number

Coverage

ELOG

csv

Coverage

PerilCode

ELOG

csv

Peril code

ErrorMessage

ELOG,REJEXP

csv

Error message

ChanceOfLoss

MELT, MPLT

csv

Probability of non-zero loss

MaxLoss

MELT, MPLT

csv

Highest point of event loss on probability distribution

MeanImpactedExposure

MELT,MPLT

csv

Mean exposure that has been affected by the event (across all samples)

MaxImpacted Exposure

MELT,MPLT

csv

Max exposure that has been affected by the event (across all samples).

FootprintNumLocs

MELT,MPLT

csv

Number of locations in the event footprint

EPType

EPT, PSEPT

csv

Describes type of EP curve: 1 = OEP, 2 = OEP TVAR, 3 = AEP, 4 = AEP TVAR

EPCalc

EPT

csv

Describes calculation method for EP curve: 1=MeanDR, 2=Full, 3=PerSampleMean, 4=MeanSample

Model

Field

Tables / File

Format

Current Oasis name

Description

FrequencyDistribution

ExtraModelMetaData

json

Frequency

LossUncertaintyDistribution

ExtraModelMetaData

json

Loss Uncertainty

SeasonalityDistribution

ExtraModelMetaData

json

Seasonality

EventId

Events

csv

Event ID

EventDescription

Events

csv

Event description

EventRate

Events

csv

Rate representing the underlying fundamental model developer rate?

EventMetaData

Events

csv

a list of event meta data (e.g. wind speed or PGA). It will be peril (and possibly vendor) specific.

ModelName

ExtraModelMetaData, AnalysisSettings

json

Model Name

ModelVersion

ExtraModelMetaData, AnalysisSettings

json

Model Version

ReleasedOn

ExtraModelMetaData

json

Model released on (date)

Vendor

ExtraModelMetaData

json

Vendor

Region

ExtraModelMetaData

json

ModeL region where losses are produced

Peril

ExtraModelMetaData

json

Wide category of peril, e.g. Wind, flood, quake, etc that model produces losses

Year

Occurrence

csv

Occurrence Year

Month

Occurrence

csv

Occurrence Month

Day

Occurrence

csv

Occurrence Day

Hour

Occurrence

csv

Occurrence Hour

Minute

Occurrence

csv

Occurrence Minute

OccID

Occurrence

csv

Occurrence ID

Period

Occurrence, Periods

csv

Period No

PeriodWeight

Periods

csv

Period Weight

Analysis

Field

Tables / File

Format

Current Oasis name

Description

AuditTrail?

AnalysisSettings?

json

ResultsTableNames

ResultsTableNames

json

A list of the results table names for this analysis

ExtraModelMetaDataFiles

ExtraModelMetaData

json

A list of other files included in the results package (e.g. Model, Occurrence, etc).

AnalysisID

AnalysisSettings

json

Analysis_tag

Analysis tag / ID

AnalysisName

AnalysisSettings

json

Analysis name

ClientName

AnalysisSettings

json

Client name

ExposureLocation

AnalysisSettings

json

Exposure_location

Exposure location

ExposureDBName

AnalysisSettings

json

Exposure database name

SourceExposureFiles

AnalysisSettings

json

List of input files (can be different numbers and kinds of files for different models)

AggregatedExposureFiles

AnalysisSettings

json

List of aggregated exposure files present

OasisVersion

AnalysisSettings

json

SystemName

AnalysisSettings

json

System name

SystemVersion

AnalysisSettings

json

System version

PortfolioSetID

AnalysisSettings

json

Prog_id

Portfolio set ID

SourceTag

AnalysisSettings

json

Source_tag

Source tag

LossThreshold

AnalysisSettings

json

LossThreshold

Loss Threshold

NumberOfSamples

AnalysisSettings

json

NumberOfSamples

Number of Samples

PerilsRun

AnalysisSettings

json

PerilsRun

Perils run (including sub-perils)

NumberOfPeriods

AnalysisSettings

json

Number of periods

PeriodLength

AnalysisSettings

json

Length of each period in years

TransformQueued

AnalysisSettings

json

TransformQueued

Transform queued

TransformStart

AnalysisSettings

json

TransformStart

Transform start

TransformFinish

AnalysisSettings

json

TransformFinish

Transform finish

RunQueued

AnalysisSettings

json

RunQueued

Run time queued

RunStart

AnalysisSettings

json

RunStart

Run time start

RunFinish

AnalysisSettings

json

RunFinish

Run time finish

AnalysisCurrency

AnalysisSettings

json

Currency of analysis in OED permitted values.

User

AnalysisSettings

json

User who ran the analsysis

ScaleFactor

AnalysisSettings

json

In case you want to scale results

ModelSettings

ModelSettings

json

e.g. demand surge, storm leakage, event set (e.g. historic, long term, etc), correlation, etc)

Perspective

AnalysisSettings

json

Perspective of loss (e.g. ground-up, gross, net, etc)

OutputLevel

Perspective

json

OutputLevel

Indicator what level outut has been run (e.g. AccNumber, PolNumber, PortNumber, LocNumber, AreaCode, LOB, etc)

AAL

Perspective

json

AAL

Indicator, whether AAL has been run

AEP

Perspective

json

AEP

Indicator, whether AEP has been run

OEP

Perspective

json

OEP

Indicator, whether OEP has been run

PerSampleAEP

Perspective

json

PerSampleAEP

Indicator, whether per sample AEP has been run

PerSampleOEP

Perspective

json

PerSampleOEP

Indicator, whether per sample OEP has been run

ELT

Perspective

json

ELT

Indicator, whether ELT has been run

PLT

Perspective

json

PLT

Indicator, whether PLT has been run

Samples

Perspective

json

Samples

Indicator, whether Samples have been run

SampleMeanAEP

Perspective

json

SampleMeanAEP

SampleMeanOEP

Perspective

json

SampleMeanOEP

PerSampleMeanAEP

Perspective

json

PerSampleMeanAEP

Keep to future proof in case clients want this

PerSampleMeanOEP

Perspective

json

PerSampleMeanOEP

Keep to future proof in case clients want this

Exposure

Field

Tables / File

Format

Current Oasis name

Description

SummaryId

Exposure

csv

Summary ID

Coverage

Exposure

csv

Coverage (building, contents, BI or other)

SourceExposure

Exposure

csv

Source Exposure

SourceNumLocs

Exposure

csv

Source number of locations