ORD tables¶
The catalogue of result tables defined by ORD, grouped by category. Each table has a
standard acronym used throughout the tooling (e.g. SELT, EPT, ALT). “In Oasis”
indicates whether the table is currently produced by the OasisLMF toolchain.
Results¶
Acronym |
Table |
Description |
In Oasis |
|---|---|---|---|
SELT |
Sample Event Loss Table |
Sample losses for each event at the appropriate summary level |
Yes |
QELT |
Quantile Event Loss Table |
Distribution of losses at user specified quantiles for each event at the appropriate summary level |
No |
MELT |
Moment Event Loss Table |
Summary stats (mean, SD etc) for each event at the appropriate summary level |
Yes |
SPLT |
Sample Period Loss Table |
Sample losses for each event within each period at the appropriate summary level |
No |
QPLT |
Quantile Period Loss Table |
Distribution of losses at user specified quantiles for each event within each period at the appropriate summary level |
No |
MPLT |
Moment Period Loss Table |
Summary stats (mean, SD etc) for each event within each period at the appropriate summary level |
Yes |
ALT |
Average Loss Table |
AAL, SD |
Yes |
EPT |
Exceedance Probability Table |
Exceedance probabilities for VARs and TVaRs of maximum and aggregate event losses in a period |
Yes |
PSEPT |
Per Sample Exceedance Probability |
Exceedance probabilities for VARs and TVaRs of maximum and aggregate event losses in a period for each sample |
Yes |
ELOG |
Error Log |
Contains error codes for locations that were failed to be processed by the model |
Yes |
DOMEXP |
Aggregate summaries of exposure within model domain |
Model specific so needs to be in the Results area |
No |
REJEXP |
Aggregate summaries of rejected exposure by reason rejected |
Model specific so needs to be in the Results area |
No |
Analysis¶
Acronym |
Table |
Description |
In Oasis |
|---|---|---|---|
Analysis MetaData json blob - see example |
File that includes metadata for each analysis. It ties everything together and enables full audit trail. |
partly |
Model¶
Acronym |
Table |
Description |
In Oasis |
|---|---|---|---|
Model MetaData json blob - not done yet |
A file that gives mandatory information about each model, including name, version number, frequency, severity and seasonality usage |
partly |
|
Event |
Contains the full set of events with optional event descriptions and the event rate provided by the modeller as well as, optionally, an OriginalEventRate field |
Yes |
|
Occurrence |
If we add an optional quantile column and then this can also serve as the RMS style PEQT |
Yes |
|
Event Footprint |
Contains information about the footprint of each event |
Yes |
|
Vulnerability |
Contains information about each vulnerability curve |
Yes |
|
Period Weights |
Or we could include PeriodWeight as an optional column in the Occurrence file |
Yes |
|
Shapefiles |
The possibility of including shapefiles should be included |
Yes |
Exposure¶
Acronym |
Table |
Description |
In Oasis |
|---|---|---|---|
Input Exposure |
Table for each input file: 2 or 4 for OED (with & without RI), different numbers of files for other vendors |
No |
|
Aggregated Exposure |
Aggregate summaries of input exposure |
No |